package egg_energy

import (
	"applet/app/db"
	"applet/app/e"
	md "applet/app/md/institutional_management/egg_energy"
	"applet/app/utils/cache"
	"code.fnuoos.com/EggPlanet/egg_models.git/src/implement"
	"code.fnuoos.com/EggPlanet/egg_models.git/src/model"
	enum2 "code.fnuoos.com/EggPlanet/egg_system_rules.git/enum"
	"code.fnuoos.com/EggPlanet/egg_system_rules.git/rule/egg_energy/enum"
	"github.com/gin-gonic/gin"
	"time"
)

// SetVideoReward
// @Summary      制度中心-蛋蛋能量-激励视频(设置)
// @Tags         蛋蛋能量
// @Description  激励视频(设置)
// @Accept       json
// @Produce      json
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @param req    body	md.SetVideoRewardReq 	true  "落地页不填页大小默认20条数据"
// @Success      200   {string}  	"success"
// @Failure      400   {object}   md.Response              	"具体错误"
// @Router       /api/institutionalManagement/eggEnergy/platformRevenue/SetVideoReward [post]
func SetVideoReward(c *gin.Context) {
	var req *md.SetVideoRewardReq
	if err1 := c.ShouldBindJSON(&req); err1 != nil {
		e.OutErr(c, e.ERR_INVALID_ARGS, err1.Error())
		return
	}

	conn := cache.GetPool().Get()
	cfgDb := implement.NewSysCfgDb(db.Db, conn)
	unitPrice, err2 := cfgDb.SysCfgGetOneNoDataNoErr(enum2.VideoReward(enum2.VideoRewardUnitPrice).String())
	if err2 != nil {
		e.OutErr(c, e.ERR_INVALID_ARGS, err2.Error())
		return
	}
	if unitPrice == nil {
		cfgDb.SysCfgInsert(enum2.VideoReward(enum2.VideoRewardUnitPrice).String(), req.UnitPrice, "激励视频单价")
	} else {
		cfgDb.SysCfgUpdate(enum2.VideoReward(enum2.VideoRewardUnitPrice).String(), req.UnitPrice)
	}

	emcp, err3 := cfgDb.SysCfgGetOneNoDataNoErr(enum2.VideoReward(enum2.VideoRewardECMP).String())
	if err3 != nil {
		e.OutErr(c, e.ERR_INVALID_ARGS, err3.Error())
		return
	}
	if emcp == nil {
		cfgDb.SysCfgInsert(enum2.VideoReward(enum2.VideoRewardECMP).String(), req.ECMP, "当前 ecmp 值")
	} else {
		cfgDb.SysCfgUpdate(enum2.VideoReward(enum2.VideoRewardECMP).String(), req.ECMP)
	}

	cfgDb.SysCfgInsert(enum2.VideoReward(enum2.VideoRewardECMP).String(), req.ECMP, "当前 ecmp 值")

	e.OutSuc(c, "success", nil)

}

// ListPlatformRevenue
// @Summary      制度中心-蛋蛋能量-平台营收数据(获取)
// @Tags         蛋蛋能量
// @Description  平台营收数据(获取)
// @Accept       json
// @Produce      json
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Param    req    body	md.ListPlatformRevenueReq 	true  "分页信息必填"
// @Success      200   {object} md.ListPlatformRevenueResp   	"具体数据"
// @Failure      400   {object}   md.Response              	"具体错误"
// @Router       /api/institutionalManagement/eggEnergy/globalData/platformRevenueList [post]
func ListPlatformRevenue(c *gin.Context) {
	var req *md.ListPlatformRevenueReq
	if err1 := c.ShouldBindJSON(&req); err1 != nil {
		e.OutErr(c, e.ERR_INVALID_ARGS, err1.Error())
		return
	}

	var kindList = []map[string]interface{}{
		{
			"name":  enum.PlatformRevenueDataKind.String(enum.AppOpenAds),
			"value": enum.AppOpenAds,
		},
		{
			"name":  enum.PlatformRevenueDataKind.String(enum.BannerAds),
			"value": enum.BannerAds,
		},
		{
			"name":  enum.PlatformRevenueDataKind.String(enum.InFeedAds),
			"value": enum.InFeedAds,
		},
		{
			"name":  enum.PlatformRevenueDataKind.String(enum.InterstitialAds),
			"value": enum.InterstitialAds,
		},
	}

	platformRevenueDataDb := implement.NewPlatformRevenueDataDb(db.Db)
	platformRevenueDataList, total, err := platformRevenueDataDb.PlatformRevenueDataFindAndCount(req.Page, req.Limit, req.StartAt, req.EndAt, req.Kind)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	list := make([]md.PlatformRevenueDataNode, len(platformRevenueDataList))
	for i, platformRevenueData := range platformRevenueDataList {
		list[i].Kind = platformRevenueData.Kind
		list[i].TotalAmount = platformRevenueData.TotalAmount
		list[i].Hours = platformRevenueData.Hours
		list[i].Memo = platformRevenueData.Memo
		list[i].BalanceTimes = platformRevenueData.BalanceTimes
		list[i].BalanceAmount = platformRevenueData.BalanceAmount
		list[i].CreateAt = platformRevenueData.CreateAt
		list[i].SystemID = platformRevenueData.Id
	}

	resp := md.ListPlatformRevenueResp{
		KindList: kindList,
		Paginate: md.Paginate{
			Limit: req.Limit,
			Page:  req.Page,
			Total: total,
		},
		List: list,
	}
	e.OutSuc(c, resp, nil)
}

// AddPlatformRevenue
// @Summary      制度中心-蛋蛋能量-平台营收数据(新增)
// @Tags         蛋蛋能量
// @Description  平台营收数据(新增)
// @Accept       json
// @Produce      json
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Param    req    body	md.AddPlatformRevenueReq 	true  "数据种类、金额、时长(最长24h)、执行次数必填,备注选填"
// @Success      200   {int}   	"插入数据 id"
// @Failure      400   {object}   md.Response              	"具体错误"
// @Router       /api/institutionalManagement/eggEnergy/platformRevenue/PlatformRevenueAdd [post]
func AddPlatformRevenue(c *gin.Context) {
	var req *md.AddPlatformRevenueReq
	if err1 := c.ShouldBindJSON(&req); err1 != nil {
		e.OutErr(c, e.ERR_INVALID_ARGS, err1.Error())
		return
	}

	platformRevenueDataDb := implement.NewPlatformRevenueDataDb(db.Db)
	now := time.Now()
	hour := now.Hour()
	if req.Hours > 24 {
		hour = 24
	}

	times := req.Hours * 60 / req.Frequency
	m := model.PlatformRevenueData{
		Kind:          req.Kind,
		TotalAmount:   req.TotalAmount,
		BalanceAmount: req.TotalAmount,
		Hours:         hour,
		BalanceTimes:  times,
		Frequency:     req.Frequency,
		Memo:          req.Memo,
		CreateAt:      now.Format("2006-01-02 15:04:05"),
		UpdateAt:      now.Format("2006-01-02 15:04:05"),
	}
	id, err := platformRevenueDataDb.PlatformRevenueDataInsert(&m)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, id, nil)
}
